pub enum DatasetError {
UnknownColumn(String),
UnsupportedColumnType {
column: String,
type_name: &'static str,
},
EncodingMismatch {
column: String,
encoding: &'static str,
column_type: &'static str,
},
NullCategorical {
column: String,
row: u32,
},
EmptySplit(Split),
InvalidFractions {
train: f64,
val: f64,
test: f64,
},
BadBatchSize(usize),
NoFeatures,
OrphanEncoding(String),
Tidy(String),
Shape(String),
}Variants
UnknownColumn(String)
UnsupportedColumnType
EncodingMismatch
NullCategorical
Categorical encoding requested but the column row at this index is null. Phase 1 does not have a null policy — this is an error.
EmptySplit(Split)
InvalidFractions
Fractions must each be in [0, 1] and sum to ≤ 1.
BadBatchSize(usize)
NoFeatures
OrphanEncoding(String)
Encoding was registered for a column not in feature_cols or
label_col.
Tidy(String)
Shape(String)